@@ -1,5 +1,5 @@
 from redis import connection as redisconn
-import asynchat
+from rs4 import asynchat
 from . import dbconnect	
 import socket
 
@@ -59,8 +59,7 @@ class AsynConnect (dbconnect.AsynDBConnect, asynchat.async_chat):
 			res = self.response [0][0]
 		except IndexError:
 			res = None
-		self.response = []
-		self.has_result = False
+		self.response = []		
 		return res
 	
 	def add_element (self, e):
