@@ -1,4 +1,4 @@
-import asyncore 
+from rs4 import asyncore 
 import re 
 import time 
 import sys 
@@ -50,7 +50,7 @@ class DBConnect:
 		self.set_event_time ()
 	
 	def close_if_over_keep_live (self):
-		if time.time () - self.event_time > self.keep_alive:		
+		if self.connected and time.time () - self.event_time > self.keep_alive:		
 			self.disconnect ()			
 			
 	def set_backend (self, backend_keep_alive = 10):
@@ -77,9 +77,9 @@ class DBConnect:
 			self.logger ("[info] ..dbo %s has been closed" % addr)			
 			self.set_active (False)
 			self.request = None
-		else:
-			self.logger ("[info] ..dbo %s was disconnected or keep alive timeout" % addr)	
-					
+		#else:
+		#	self.logger ("[info] ..dbo %s was disconnected or keep alive timeout" % addr)		
+
 	def get_history (self):
 		return self.__history
 		
@@ -92,21 +92,15 @@ class DBConnect:
 			self.__no_more_request = False
 			return 0
 	
-	def empty_cursor (self):
-		if self.has_result:
-			self.fetchall ()			
-	
 	def maintern (self, object_timeout):
-		# query done but not used
-		if self.has_result and self.isactive () and time.time () - self.event_time > self.zombie_timeout:			
-			self.empty_cursor ()
-			self.set_active (False)
-			
-		if time.time () - self.event_time > object_timeout:
-			if not self.isactive ():
-				self.disconnect ()
-				return True # deletable
-		return False	
+		# when in map, mainteren by lifetime with zombie_timeout
+		if self.is_channel_in_map ():
+			return False
+		idle = time.time () - self.event_time		
+		if idle > object_timeout:				
+			self.close (1)
+			return True # deletable
+		return False
 	
 	def reconnect (self):
 		self.disconnect ()
@@ -132,10 +126,11 @@ class DBConnect:
 			self.active = flag
 			return
 		
-		self.lock.acquire ()
-		self.active = flag
-		self.request_count += 1		
-		self.lock.release ()
+		with self.lock:
+			self.active = flag
+			self.request_count += 1		
+			if not flag:
+				self.has_result = False		
 	
 	def get_active (self, nolock = False):
 		if nolock or self.lock is None:
@@ -220,13 +215,7 @@ class AsynDBConnect (DBConnect):
 		if map is None:
 			map = self._map
 		return self._fileno in map
-	
-	def maintern (self, object_timeout):
-		# when in map, mainteren by lifetime with zombie_timeout
-		if self.is_channel_in_map ():
-			return False
-		return DBConnect.maintern (self, object_timeout)
-		
+
 	def del_channel (self, map=None):
 		# do not remove self._fileno
 		fd = self._fileno
